@@ -1100,6 +1100,7 @@ InstanceTypeType = Literal[
     "c6in.4xlarge",
     "c6in.8xlarge",
     "c6in.large",
+    "c6in.metal",
     "c6in.xlarge",
     "c7g.12xlarge",
     "c7g.16xlarge",
@@ -1348,6 +1349,7 @@ InstanceTypeType = Literal[
     "m6idn.4xlarge",
     "m6idn.8xlarge",
     "m6idn.large",
+    "m6idn.metal",
     "m6idn.xlarge",
     "m6in.12xlarge",
     "m6in.16xlarge",
@@ -1357,6 +1359,7 @@ InstanceTypeType = Literal[
     "m6in.4xlarge",
     "m6in.8xlarge",
     "m6in.large",
+    "m6in.metal",
     "m6in.xlarge",
     "m7g.12xlarge",
     "m7g.16xlarge",
@@ -1507,6 +1510,7 @@ InstanceTypeType = Literal[
     "r6idn.4xlarge",
     "r6idn.8xlarge",
     "r6idn.large",
+    "r6idn.metal",
     "r6idn.xlarge",
     "r6in.12xlarge",
     "r6in.16xlarge",
@@ -1516,6 +1520,7 @@ InstanceTypeType = Literal[
     "r6in.4xlarge",
     "r6in.8xlarge",
     "r6in.large",
+    "r6in.metal",
     "r6in.xlarge",
     "r7g.12xlarge",
     "r7g.16xlarge",
